Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(151)

Unified Diff: third_party/WebKit/public/web/WebFrameClient.h

Issue 2797813002: Replicate feature policy container policies. (Closed)
Patch Set: Update pending container policy more often; add test Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/web/WebFrameClient.h
diff --git a/third_party/WebKit/public/web/WebFrameClient.h b/third_party/WebKit/public/web/WebFrameClient.h
index 64cb69786f7f98f45f6d774868a1d73920f8b7c5..8f560d180cfdd194405728f4704aa60e66802702 100644
--- a/third_party/WebKit/public/web/WebFrameClient.h
+++ b/third_party/WebKit/public/web/WebFrameClient.h
@@ -179,12 +179,14 @@ class BLINK_EXPORT WebFrameClient {
// to prevent the new child frame from being attached. Otherwise, embedders
// should create a new WebLocalFrame, insert it into the frame tree, and
// return the created frame.
- virtual WebLocalFrame* CreateChildFrame(WebLocalFrame* parent,
- WebTreeScopeType,
- const WebString& name,
- const WebString& fallback_name,
- WebSandboxFlags sandbox_flags,
- const WebFrameOwnerProperties&) {
+ virtual WebLocalFrame* CreateChildFrame(
+ WebLocalFrame* parent,
+ WebTreeScopeType,
+ const WebString& name,
+ const WebString& fallback_name,
+ WebSandboxFlags sandbox_flags,
+ const WebParsedFeaturePolicy& container_policy,
+ const WebFrameOwnerProperties&) {
return nullptr;
}
@@ -222,9 +224,12 @@ class BLINK_EXPORT WebFrameClient {
virtual void DidUpdateToUniqueOrigin(
bool is_potentially_trustworthy_unique_origin) {}
- // The sandbox flags have changed for a child frame of this frame.
- virtual void DidChangeSandboxFlags(WebFrame* child_frame,
- WebSandboxFlags flags) {}
+ // The sandbox flags or container policy have changed for a child frame of
+ // this frame.
+ virtual void DidChangeFramePolicy(
+ WebFrame* child_frame,
+ WebSandboxFlags flags,
+ const WebParsedFeaturePolicy& container_policy) {}
// Called when a Feature-Policy HTTP header is encountered while loading the
// frame's document.

Powered by Google App Engine
This is Rietveld 408576698